@@ -28,6 +28,8 @@ __PACKAGE__->mk_accessors(
         )
 );
 
+our $VERSION = '0.04';
+
 sub init {
     my $self = shift;
     $self->SUPER::init(@_);
@@ -78,7 +80,7 @@ sub fetch_results {
             $res{$field} = $hiliter->light($str);
         }
         push @results, \%res;
-        last if ++$count > $page_size;
+        last if ++$count >= $page_size;
     }
     return \@results;
 }
